@@ -80,11 +80,16 @@ pub fn build_cli() -> App<'static, 'static> {
              .help("Descend at most LEVELS of directories below DIR")
              .takes_value(true)
              .value_name("LEVELS"))
+        .arg(Arg::with_name("full_path")
+            .long("full-path")
+            .help("Match REGEX against the full directory path")
+            .long_help("By default, REGEX matches against only the directory name. Using this flag, REGEX matches against the full canonical path."))
         .arg(Arg::with_name("regex")
             .short("r")
             .long("regex")
-            .help("Filters command to repo(s) matching provided Regex")
+            .help("Filters command to repo(s) matching provided regular expression")
             .takes_value(true)
+            .value_name("REGEX")
             .default_value(".*"))
         .arg(Arg::with_name("cmd")
              .help("A single git command to run in each repo")
